<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:fo="http://www.w3.org/1999/XSL/Format"
	xmlns:date="http://exslt.org/dates-and-times"
	extension-element-prefixes="date" 
	version="1.0">
	<xsl:output method="xml" indent="yes" />
	<xsl:variable name="now" select="date:date-time()" />
	<xsl:param name="HOCHSCHUL_NAME" />
	<xsl:param name="IMG_HEADER_LOGO" />
	<xsl:param name="ROOT_DIR" />
	<xsl:param name="IMAGEURL_HISINONE" />
	<xsl:param name="HOCHSCHUL_URL" />
	
	<!-- Root-Einsprungspunkt Seitendefinition 
		xsl:template match muss auf das Root-Element der XML-Datei angepaßt werden -->
	
	<xsl:template match="raumBelegungen">
		<xsl:variable name="font-size">10</xsl:variable>
		<xsl:variable name="width" select="@width" />
		<xsl:variable name="height" select="@height" />
		<xsl:variable name="pageWidth" select="@pageWidth" />
		<xsl:variable name="pageHeight" select="@pageHeight" />
		<xsl:variable name="pdfPlanLeft" select="@pdfPlanLeft" />
		<xsl:variable name="pdfPlanRight" select="@pdfPlanRight" />
		<xsl:variable name="pdfPlanTop" select="@pdfPlanTop" />
		<xsl:variable name="pdfPlanBottom" select="@pdfPlanBottom" />
		<xsl:variable name="headerText" select="@headerText" />
		<xsl:variable name="marginTop" select="@marginTop" />
		<xsl:variable name="marginBottom" select="@marginBottom" />
		
		<fo:root>
			<fo:layout-master-set>
				<!-- Seitengröße inkl. der Ränder festlegen -->
				<fo:simple-page-master master-name="cover"
					page-height="{$pageHeight}mm" 
					page-width="{$pageWidth}mm" 
					margin-top="{$pdfPlanTop}mm"
					margin-bottom="{$pdfPlanBottom}mm" 
					margin-left="{$pdfPlanLeft}mm" 
					margin-right="{$pdfPlanRight}mm">
					<fo:region-body margin-top="{$marginTop}mm"
						margin-bottom="{$marginBottom}mm" />
					<fo:region-before extent="0cm" />
					<fo:region-after extent="0cm" />
				</fo:simple-page-master>
				
				<!-- Die weiteren Seiten mit der Legende sind in A4 hoch-->
				<fo:simple-page-master master-name="follow"
					page-height="297mm" 
					page-width="210mm" 
					margin-top="15mm"
					margin-bottom="15mm" 
					margin-left="25mm" 
					margin-right="25mm">
					<fo:region-body margin-top="{$marginTop}mm"
						margin-bottom="{$marginBottom}mm" />
					<fo:region-before extent="0cm" />
					<fo:region-after extent="0cm" />
				</fo:simple-page-master>
				
				<fo:page-sequence-master master-name="contents">
					<fo:single-page-master-reference
						master-reference="cover" page-position="first" />
					<fo:repeatable-page-master-reference
						master-reference="follow" page-position="any" />
				</fo:page-sequence-master>
			</fo:layout-master-set>
			
			<xsl:for-each select="raumBelegung">
				<xsl:call-template name="raumBelegung" />
			</xsl:for-each>
			
			<!-- 
			<fo:block id="last-page" />
			 -->
		</fo:root>
	</xsl:template>	
	
	<xsl:template name="raumBelegung">
		<xsl:variable name="font-size">10</xsl:variable>
		<fo:page-sequence master-reference="contents" language="de">
			<!-- Kopfzeile der Seite definieren mit Inhalten füllen -->
			<fo:static-content flow-name="xsl-region-before"
				font-size="{$font-size}" width="100%">
				<fo:block-container position="absolute" width="100%">
					<fo:block-container position="absolute" left="75%" right="0cm">
						<fo:block text-align="right">
							
						</fo:block>
					</fo:block-container>
					<fo:block-container position="absolute" right="25%" left="0cm">
						<fo:block>
							<xsl:value-of select="$HOCHSCHUL_NAME" />
						</fo:block>
							
						<fo:block font-size="150%" vertical-align="middle">
							<fo:block>
								<xsl:value-of select="@headerText" />
							</fo:block>
							<fo:leader rule-thickness="1px"
								leader-length="85%" color="black" />
						</fo:block>
					</fo:block-container>
				</fo:block-container>
				
			</fo:static-content>
			<!-- ENDE der Kopfzeilendefinition -->
			
			<!-- Fußzeile der Seite definieren mit Inhalten füllen -->
			<fo:static-content flow-name="xsl-region-after"
				font-size="{$font-size}">
				
				<fo:block font-size="0.5em" text-align="right">
					Erstellt am 
					<xsl:value-of select="date:format-date($now, 'EEE, dd.MM.yyyy')"/>
					um
					<xsl:value-of select="date:format-date($now, 'HH:mm')"/>
                       Uhr
				</fo:block>
				
			</fo:static-content>
			<!-- ENDE der Fußzeilendefinition -->
			
			<!-- Initialisieren des Haupt-Druckbereiches -->
			<fo:flow flow-name="xsl-region-body"
				font-size="{$font-size}">
				<!--  

				THE ERROR OCCURES BECAUSE OF THE FOLLOWING POSITIONING,

				replace with <fo:block-container> to make it work in FOP 2.0
			-->
				<fo:block-container position="absolute" 
					left="0cm" 
					top="0cm"
					right="0cm"
					bottom="0cm">
					<fo:block />
						
					<!-- Legende -->
					<xsl:call-template name="legend" /> 
					
					<!-- Zeitlegende initialisieren -->
					<xsl:for-each select="planTimeline">
						<xsl:call-template name="planTimeline" />
					</xsl:for-each>
					
					<!-- Spalten initialisieren -->
					<xsl:for-each select="planColumn">
						<xsl:call-template name="planColumn" />
					</xsl:for-each>
					
				</fo:block-container>
				<xsl:if test="planColumn[planColumnTermin[@showDetails='no']]">
					<fo:block page-break-before="always" />
					<fo:list-block>
						<xsl:for-each select="planColumn[planColumnTermin[@showDetails='no']]">
							<fo:list-item>
								<fo:list-item-label>
									<fo:block />
								</fo:list-item-label>
								
								<fo:list-item-body>
								 	<fo:block font-weight="bold" font-size="120%" margin-top="1em">
								 		<xsl:value-of select="@columnTitle" />
								 	</fo:block>
									
									<fo:list-block>
										<xsl:for-each select="planColumnTermin[@showDetails='no']">
											<xsl:call-template name="extentionalLegend" />
										</xsl:for-each>
									</fo:list-block>
								</fo:list-item-body>
							</fo:list-item>
						</xsl:for-each>
					</fo:list-block>
				</xsl:if>

			</fo:flow>
			<!-- Initialisierung ENDE -->
		</fo:page-sequence>
	</xsl:template>
	
	<!-- Legende -->
	<xsl:template name="legend">
		<fo:block-container 
			position="absolute" 
			font-size="0.7em"
			top="147mm"
			z-index="1">
				
			<fo:block>
				<xsl:for-each select="legend/rhythmus">
					<xsl:variable name="backgroundcolor" select="@background-color" />
						
					<fo:block keep-together="always">
						<fo:inline width="2cm" height="2cm" 
							background-color="{$backgroundcolor}" 
							border="0.5px solid black"
							keep-with-next="always">
							&#160;
						</fo:inline>
						<fo:inline keep-with-previous="always">
							<xsl:value-of select="." />
						</fo:inline>
					</fo:block>
						
				</xsl:for-each>
			</fo:block>
		</fo:block-container>
	</xsl:template>
	
	<!-- Zeitleiste -->
	<xsl:template name="planTimeline">
		<xsl:variable name="top"><xsl:value-of select="@top" /></xsl:variable>
		<xsl:variable name="width"><xsl:value-of select="@width" /></xsl:variable>
		<xsl:variable name="height"><xsl:value-of select="@height" /></xsl:variable>
		<xsl:variable name="timeLineWidth"><xsl:value-of select="@timeLineWidth" /></xsl:variable>
		<fo:block-container 
			position="absolute" 
			top="{$top}mm"
			z-index="1">
			<fo:block border-top="1px dashed grey" margin-top="0px">
				<fo:block-container width="{$timeLineWidth}mm" height="{$height}mm" overflow="hidden">
					<fo:block>
						<xsl:value-of select="." /> Uhr
					</fo:block>
				</fo:block-container>
			</fo:block>
		</fo:block-container>
	</xsl:template>
	
	<!-- Spalten -->
	<xsl:template name="planColumn">
		<xsl:variable name="width"><xsl:value-of select="@width" /></xsl:variable>
		<xsl:variable name="left"><xsl:value-of select="@left" /></xsl:variable>
		<xsl:variable name="height"><xsl:value-of select="@height" /></xsl:variable>
		<xsl:variable name="background-color">
			<xsl:choose>
				<xsl:when test="@background-color != ''">
					<xsl:value-of select="@background-color" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>transparent</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<fo:block-container 
			position="absolute"
			width="{$width}mm" 
			left="{$left}mm" 
			height="{$height}mm"
			padding-right="-1px"
			z-index="50"
			border="1px dashed grey"
			border-top="none">
			<fo:block 
				margin-top="-1.5em" 
				height="1em" 
				width="100%" 
				background-color="{$background-color}"
				border="1px dashed grey"
				text-align="center" 
				padding-bottom="1px"
				padding-right="-1px"
				border-bottom="none">
				<xsl:value-of 
					select="@columnTitle" />
				<fo:block>
					<xsl:value-of select="@unusedDayName" />
				</fo:block>
			</fo:block>
			
			<xsl:for-each select="planColumnTermin[@showDetails='no']">
				<xsl:call-template name="planColumnTerminNoDetails" />
			</xsl:for-each>
			<xsl:for-each select="planColumnTermin[not (@showDetails)]">
				<xsl:call-template name="planColumnTermin" />
			</xsl:for-each>
			
		</fo:block-container>
	</xsl:template>
	
	<!-- Einzelne Termine -->
	<xsl:template name="planColumnTermin">
		<xsl:variable name="width"><xsl:value-of select="@width" /></xsl:variable>
		<xsl:variable name="position"><xsl:value-of select="@position" /></xsl:variable>
		<xsl:variable name="height"><xsl:value-of select="@height" /></xsl:variable>
		<xsl:variable name="top"><xsl:value-of select="@top" /></xsl:variable>
		<xsl:variable name="background-color"><xsl:value-of select="@background-color" /></xsl:variable>
		
		<fo:block-container 
			position="absolute"
			width="{$width}mm" 
			left="{$position}mm"
			top="{$top}mm" 
			height="{$height}mm" 
			border="1px solid black"
			background-color="{$background-color}"
			text-align="left"
			z-index="99"
			font-size="0.75em"
			padding-top="-1px"
			padding-right="-1px"
			overflow="hidden">
			
			<!-- Bereich zur Definition der Legende zu Elementen, die zu klein dargestellt werden, um detailierte Informationen zu enthalten -->
			<xsl:choose>
				<xsl:when test="@showDetails='no'">
					<fo:block font-weight="bold">
						<fo:block>
							<xsl:number value="position()" format="1) " />
						</fo:block>
						<xsl:value-of select="veranstaltungstitel" />
					</fo:block>
				</xsl:when>
				<xsl:otherwise>
					<fo:block>
						<!-- elementnr -->
						<xsl:if test="elementnr != ''">
							<fo:inline font-weight="bold">
								<xsl:value-of select="elementnr" />
								<xsl:text>&#160;</xsl:text>
							</fo:inline>
						</xsl:if>
						
						
					</fo:block>		
				</xsl:otherwise>
			</xsl:choose>
			
		</fo:block-container>
	</xsl:template>
	
	
	<!-- Einzelne Termine (Leere Elemente mit Verweis auf die Legende; nächste Seite) -->
	<xsl:template name="planColumnTerminNoDetails">
		<xsl:variable name="width"><xsl:value-of select="@width" /></xsl:variable>
		<xsl:variable name="position"><xsl:value-of select="@position" /></xsl:variable>
		<xsl:variable name="height"><xsl:value-of select="@height" /></xsl:variable>
		<xsl:variable name="top"><xsl:value-of select="@top" /></xsl:variable>
		<xsl:variable name="background-color"><xsl:value-of select="@background-color" /></xsl:variable>
		
		<fo:block-container 
			position="absolute"
			width="{$width}mm" 
			left="{$position}mm"
			top="{$top}mm" 
			height="{$height}mm" 
			border="1px solid black"
			background-color="{$background-color}"
			text-align="left"
			z-index="99"
			font-size="0.75em"
			padding-top="-1px"
			padding-right="-1px"
			overflow="hidden">
			
			<!-- Bereich zur Definition der Legende zu Elementen, die zu klein dargestellt werden, um detailierte Informationen zu enthalten -->
			<fo:block font-weight="bold">
				<fo:block>
					<xsl:number value="position()" format="1) " />
				</fo:block>
				<!-- <xsl:value-of select="veranstaltungstitel" /> -->
			</fo:block>
			
		</fo:block-container>
	</xsl:template>
	
	
	<!-- Aufbau einer Legende auf einer weiteren Seite -->
	<xsl:template name="extentionalLegend">
		
		<fo:list-item keep-together.within-page="always">
			<fo:list-item-label>
				<fo:block wrap-option="wrap">
					<xsl:number value="position()" format="1) " />
				</fo:block>
			</fo:list-item-label>
			<fo:list-item-body margin-left="20pt">
				
				<fo:block>
					<!-- elementnr -->
					<xsl:if test="elementnr != ''">
						<fo:inline font-weight="bold">
							<xsl:value-of select="elementnr" />
							<xsl:text>&#160;</xsl:text>
						</fo:inline>
					</xsl:if>
					
					<!-- Veranstakltungstitel -->
					
				</fo:block>
							
				<!-- Uhrzeiten -->
				<fo:block>
					<xsl:if test="beginnzeit != ''">
						<fo:inline font-style="italic">
							von <xsl:value-of select="beginnzeit" /> 
						</fo:inline>
					</xsl:if>
					<xsl:if test="endezeit != ''">
						<fo:inline font-style="italic">
							bis <xsl:value-of select="endezeit" /> 
						</fo:inline>
					</xsl:if>
				</fo:block>
				
				<!-- Rhythmus -->
				 <fo:block>
					<xsl:if test="rhythmdefaulttext != ''">
						<fo:inline>
							<xsl:value-of select="rhythmdefaulttext" />
							<xsl:text>&#160;</xsl:text>
						</fo:inline>
					</xsl:if>
					<xsl:if test="rhythmshorttext != ''">
						<fo:inline>
							<xsl:value-of select="rhythmshorttext" />
							<xsl:text>&#160;</xsl:text>
						</fo:inline>
					</xsl:if>
					<xsl:if test="rhythmlongtext != ''">
						<fo:inline>
							<xsl:value-of select="rhythmlongtext" />
						</fo:inline>
					</xsl:if>
				</fo:block>		 		
				
			</fo:list-item-body>
		</fo:list-item>
	</xsl:template>
</xsl:stylesheet>